@@ -9,7 +9,7 @@ dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years
 
 dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")
 
-dialogId("del-m-tus", "font_small", "You and your 'feelings’. Besides, we’re not supposed to be giving any hints.")
+dialogId("del-m-tus", "font_small", "You and your ‘feelings’. Besides, we’re not supposed to be giving any hints.")
 
 dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")
 
