@@ -2,7 +2,7 @@
 dialogId("dlg-x-poster1", "font_poster", "Occupation of the captive we are sending to you is an ocean god. Except of the plane and ship disappearings (so called Sea Battle case) he is responsible for the other crimes as well, moving the continents (code name Run, continent, run) and meteorite in Tunguzka (code Jumping Jack) are among them.")
 dialogStr("Delo ujetnika, ki ti ga pošiljamo, je biti morski bog. Poleg izginjanja letal in ladij (t.i. primer Morska Bitka) je odgovoren tudi za ostale zločine, premikanje celin (kodno ime Teci, celina, teci) in meteorit v Tunguski (kodno ime Cepetavček) sta med njimi.")
 
-dialogId("dlg-x-poster2", "font_poster", "We managed to intervene just in the nick of time: we have found a brand new unwrapped box with a table game called STAR WARS in the captive's house.")
+dialogId("dlg-x-poster2", "font_poster", "We managed to intervene just in the nick of time: we have found a brand new unwrapped box with a table game called STAR WARS in the captive’s house.")
 dialogStr("Uspelo nam je posredovati, ravno še pravi trenutek: našli smo odprto čisto novo škatlo z namizno igro VOJNA ZVEZD v ujetnikovi hiši.")
 
 dialogId("dlg-x-poster3", "font_poster", "You can find the records of his sea battles in the attachement.")
