@@ -3,7 +3,7 @@ dialogId("vrak-m-knihy0", "font_small", "ESP")
 dialogStr("Aussersinnliche Wahrnehmung.")
 
 
-dialogId("vrak-v-vyhodit", "font_big", "I`d throw out these, for example.")
+dialogId("vrak-v-vyhodit", "font_big", "I’d throw out these, for example.")
 dialogStr("Ich würde die hier zum Beispiel wegschmeissen:")
 
 
