@@ -15,7 +15,7 @@ dialogId("dr-v-mozna", "font_big", "Maybe they sank her on purpose. Warriors wou
 dialogStr("Może celowo ją zatopili? Wojownicy zawsze towarzyszyli swojemu przywódcy do Walhalli.")
 
 
-dialogId("dr-m-hruza", "font_small", "That's awful. They look like they're still alive.")
+dialogId("dr-m-hruza", "font_small", "That’s awful. They look like they’re still alive.")
 dialogStr("Okropność... Siedzą tu jak żywi...")
 
 
