@@ -31,14 +31,14 @@ node_bestSolution("crabshow", 340, "Gabor Braun")
 node_bestSolution("elevator2", 455, "Gabor Braun")
 node_bestSolution("atlantis", 531, "Uoti Urpala")
  
-node_bestSolution("corals", 254, "Erik Hajduk")
+node_bestSolution("corals", 252, "David Glass")
 node_bestSolution("labyrinth", 278, "Mark Byers")
 node_bestSolution("imprisoned", 275, "Josef Peterka")
 node_bestSolution("society", 110, "Radovan Málek")
 node_bestSolution("creatures", 447, "Josef Peterka")
 node_bestSolution("cancan", 578, "Mark Byers")
 node_bestSolution("pearls", 475, "Erik Hajduk")
-node_bestSolution("turtle", 654, "Masaaki Irie")
+node_bestSolution("turtle", 620, "Zmiter Nikitin")
  
 node_bestSolution("computer", 156, "Josef Peterka")
 node_bestSolution("noground", 44, "Heiko Luettges")
@@ -46,7 +46,7 @@ node_bestSolution("bathroom", 90, "Josef Peterka")
 node_bestSolution("duckie", 98, "Ronny Standtke")
 node_bestSolution("puzzle", 144, "Josef Peterka")
 node_bestSolution("dump", 426, "Josef Peterka")
-node_bestSolution("barrel", 1364, "Gabor Braun")
+node_bestSolution("barrel", 1237, "Zmiter Nikitin")
  
 node_bestSolution("cabin1", 168, "Pavel Danihelka")
 node_bestSolution("snowman", 66, "Pavel Danihelka")
@@ -60,8 +60,8 @@ node_bestSolution("reactor", 163, "Pavel Danihelka")
 node_bestSolution("magnet", 408, "Josef Peterka")
 node_bestSolution("engine", 256, "Gabor Braun")
 node_bestSolution("steel", 185, "Josef Peterka")
-node_bestSolution("corridor", 528, "Gabor Braun")
-node_bestSolution("experiments", 710, "Erik Hajduk")
+node_bestSolution("corridor", 523, "Amic Frouvelle")
+node_bestSolution("experiments", 706, "Zmiter Nikitin")
 node_bestSolution("propulsion", 2046, "Gabor Braun")
  
 node_bestSolution("aztec", 376, "Mark Byers")
@@ -69,14 +69,14 @@ node_bestSolution("gems", 59, "Mark Byers")
 node_bestSolution("chest", 279, "Gabor Braun")
 node_bestSolution("alibaba", 459, "Gabor Braun")
 node_bestSolution("cave", 186, "Josef Peterka")
-node_bestSolution("grail", 1725, "Gabor Braun")
+node_bestSolution("grail", 1691, "Zmiter Nikitin")
  
 node_bestSolution("tetris", 134, "Gabor Braun")
 node_bestSolution("emulator", 620, "Gabor Braun")
 node_bestSolution("warcraft", 573, "Josef Peterka")
-node_bestSolution("windoze", 549, "David Glass")
-node_bestSolution("hardware", 631, "Masaaki Irie")
-node_bestSolution("floppy", 998, "Gabor Braun")
+node_bestSolution("windoze", 537, "Zmiter Nikitin")
+node_bestSolution("hardware", 629, "Zmiter Nikitin")
+node_bestSolution("floppy", 950, "Zmiter Nikitin")
  
 node_bestSolution("hanoi", 404, "Masaaki Irie")
 node_bestSolution("rush", 852, "Miroslav Olšák")
@@ -84,8 +84,8 @@ node_bestSolution("fdto", 243, "Masaaki Irie")
 node_bestSolution("rotate", 213, "Masaaki Irie")
 node_bestSolution("nowall", 418, "Masaaki Irie")
 node_bestSolution("hole", 459, "Masaaki Irie")
-node_bestSolution("key", 560, "Masaaki Irie")
+node_bestSolution("key", 554, "Zmiter Nikitin")
 node_bestSolution("keys", 281, "Erik Hajduk")
-node_bestSolution("linux", 665, "Masaaki Irie")
+node_bestSolution("linux", 605, "Zmiter Nikitin")
 
-node_bestSolution("electromagnet", 480, "Erik Hajduk")
+node_bestSolution("electromagnet", 464, "Zmiter Nikitin")
